@@ -14,6 +14,8 @@
 #' \code{filter_spec()} filters an Open Specy object.
 #'
 #' @param x an \code{OpenSpecy} object, typically with unknowns.
+#' @param conform Whether to conform the spectra to the library wavenumbers or not.
+#' @param type the type of conformation to make returned by \code{conform_spec()}
 #' @param library an \code{OpenSpecy} or \code{glmnet} object representing the
 #' reference library of spectra or model to use in identification.
 #' @param na.rm logical; indicating whether missing values should be removed
@@ -93,11 +95,30 @@ cor_spec.default <- function(x, ...) {
 #' @rdname match_spec
 #'
 #' @export
-cor_spec.OpenSpecy <- function(x, library, na.rm = T, ...) {
+cor_spec.OpenSpecy <- function(x, library, na.rm = T, conform = F,
+                               type = "roll", ...) {
+  if(conform) x <- conform_spec(x, library$wavenumber, res = NULL, type)
+
+  if(!is.null(attr(x, "intensity_unit")) &&
+     attr(x, "intensity_unit") != attr(library,  "intensity_unit"))
+    warning("Intensity units between the library and unknown are not the same")
+
+  if(!is.null(attr(x, "derivative_order")) &&
+     attr(x, "derivative_order") != attr(library,  "derivative_order"))
+    warning("Derivative orders between the library and unknown are not the same")
+
+  if(!is.null(attr(x, "baseline")) &&
+     attr(x, "baseline") != attr(library,  "baseline"))
+    warning("Baselines between the library and unknown are not the same")
+
+  if(!is.null(attr(x, "spectra_type")) &&
+     attr(x, "spectra_type") != attr(library,  "spectra_type"))
+    warning("Spectra types between the library and unknown are not the same")
+
   if(sum(x$wavenumber %in% library$wavenumber) < 3)
     stop("there are less than 3 matching wavenumbers in the objects you are ",
-         "trying to correlate; this won't work for correlation analysis. ",
-         "Consider first conforming the spectra to the same wavenumbers.",
+         "trying to correlate; this won't work for correlation analysis; ",
+         "consider first conforming the spectra to the same wavenumbers",
          call. = F)
 
   if(!all(x$wavenumber %in% library$wavenumber))
@@ -134,11 +155,12 @@ match_spec.default <- function(x, ...) {
 #' @rdname match_spec
 #'
 #' @export
-match_spec.OpenSpecy <- function(x, library, na.rm = T, top_n = NULL,
-                                 order = NULL, add_library_metadata = NULL,
+match_spec.OpenSpecy <- function(x, library, na.rm = T, conform = F,
+                                 type = "roll", top_n = NULL, order = NULL,
+                                 add_library_metadata = NULL,
                                  add_object_metadata = NULL, fill = NULL, ...) {
   if(is_OpenSpecy(library)) {
-    res <- cor_spec(x, library = library) |>
+    res <- cor_spec(x, library = library, conform = conform, type = type) |>
       ident_spec(x, library = library, top_n = top_n,
                  add_library_metadata = add_library_metadata,
                  add_object_metadata = add_object_metadata)
@@ -259,6 +281,11 @@ filter_spec.OpenSpecy <- function(x, logic, ...) {
   x$spectra <- x$spectra[, logic, with = F]
   x$metadata <- x$metadata[logic,]
 
+  if(ncol(x$spectra) == 0 | ncol(x$metadata) == 0)
+    stop("the OpenSpecy object created contains zero spectra, this is not well ",
+         "supported, if you have specific scenarios where this is required ",
+         "please share it with the developers and we can make a workaround")
+
   return(x)
 }
 
